package Bencher::Scenario::Example;

our $DATE = '2015-10-09'; # DATE
our $VERSION = '0.02'; # VERSION

our $scenario = {
    participants => [
        {fcall_template => q[Text::Wrap::wrap('', '', <text>)]},
    ],
    datasets => [
        { name=>"foobar x100",   args => {text=>"foobar " x 100} },
        { name=>"foobar x1000",  args => {text=>"foobar " x 1000} },
        { name=>"foobar x10000", args => {text=>"foobar " x 10000} },
    ],
};

1;
# ABSTRACT: An example scenario

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenario::Example - An example scenario

=head1 VERSION

This document describes version 0.02 of Bencher::Scenario::Example (from Perl distribution Bencher), released on 2015-10-09.

=head1 SYNOPSIS

 % bencher -m Example [other options]...

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
